@@ -143,7 +143,9 @@ def map_invposnormal(x0,sigma):
     def map(x):
         if not (0 <= x <= 1.0): raise ValueError
         x = erfc0 + (1.0 - erfc0) * x
-        return 1.0/(x0 - math.sqrt(2) * sigma * SS.erfinv(1.0 - 2.0*x))
+        r = 1.0/(x0 - math.sqrt(2) * sigma * SS.erfinv(1.0 - 2.0*x))
+        if r < 0: raise ValueError
+        return r
 
     return map
 
